# Simple Group Factor Analysis
Decomposes a set of expressions into a group expression.
The expression regulation can be studied via an ANOVA that
relates it to the observables in the journal file. The
final p values are then FDR corrected and the resulting
q values are produced.

The journal and analyte expression file must be ordered
the same way with respect to the samples that are
positioned on the columns.

Install with:
pip install  --index-url https://test.pypi.org/simple/ impetuous-gfa

Visit the active code via:
https://github.com/richardtjornhammar/impetuous

Visit the published code: 
https://doi.org/10.5281/zenodo.2594691

Cite using 
DOI: 10.5281/zenodo.2594691
